/// <reference types="node" resolution-mode="require"/>
import { Libp2p } from '@cerc-io/libp2p';
import { Pushable } from 'it-pushable';
import { WebRTCDirectComponents } from '@cerc-io/webrtc-direct';
import type { Transport } from '@libp2p/interface-transport';
import type { Stream as P2PStream, Connection } from '@libp2p/interface-connection';
import type { PeerInfo } from '@libp2p/interface-peer-info';
import type { Message } from '@libp2p/interface-pubsub';
import type { PeerId } from '@libp2p/interface-peer-id';
import { Multiaddr } from '@multiformats/multiaddr';
export declare const CHAT_PROTOCOL = "/chat/1.0.0";
export declare const ERR_PROTOCOL_SELECTION = "protocol selection failed";
export declare class Peer {
    _node?: Libp2p;
    _wrtcTransport: (components: WebRTCDirectComponents) => Transport;
    _relayNodeMultiaddr: Multiaddr;
    _peerStreamMap: Map<string, Pushable<any>>;
    _messageHandlers: Array<(peerId: PeerId, message: any) => void>;
    _topicHandlers: Map<string, Array<(peerId: PeerId, data: any) => void>>;
    _peerHeartbeatIntervalIdsMap: Map<string, NodeJS.Timer>;
    constructor(relayNodeURL: string, nodejs?: boolean);
    get peerId(): PeerId | undefined;
    get node(): Libp2p | undefined;
    init(): Promise<void>;
    close(): Promise<void>;
    broadcastMessage(message: any): void;
    floodMessage(topic: string, msg: any): Promise<void>;
    subscribeMessage(handler: (peerId: PeerId, message: any) => void): () => void;
    subscribeTopic(topic: string, handler: (peerId: PeerId, data: any) => void): () => void;
    _handleChangeProtocols({ peerId, protocols }: {
        peerId: PeerId;
        protocols: string[];
    }): Promise<void>;
    _dialRelay(): Promise<void>;
    _handleDiscovery(peer: PeerInfo): void;
    _handleConnect(connection: Connection): Promise<void>;
    _handleDeadConnections(remotePeerId: PeerId): Promise<void>;
    _startHeartbeatChecks(peerId: PeerId, handleDisconnect: () => Promise<void>): Promise<void>;
    _validatePing(peerId: PeerId, handleDisconnect: () => Promise<void>): Promise<void>;
    _handleDisconnect(connection: Connection): Promise<void>;
    _stopHeartbeatChecks(peerId: PeerId): void;
    _connectPeer(peer: PeerInfo): Promise<void>;
    _handleStream(peerId: PeerId, stream: P2PStream): void;
    _handleMessage(msg: Message): void;
}
